YAPC
====

Python version of the NASA Goddard Space Flight Center *"Yet Another Photon Classifier"* (YAPC)
Program for ATL03 Global Geolocated Photon Data from the NASA ICESat-2 mission

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    getting_started/Install.rst
    getting_started/Overview.rst
    getting_started/Contributing.rst
    getting_started/Resources.rst
    getting_started/Citations.rst

.. toctree::
    :maxdepth: 1
    :hidden:
    :caption: User Guide

    user_guide/append_YAPC_ICESat2_ATL03.rst
    user_guide/classify_photons.rst
    user_guide/utilities.rst

